# ALife Data Standards - Python Development Utilities

[![Python application](https://github.com/alife-data-standards/alife-std-dev-python/actions/workflows/python-app.yml/badge.svg)](https://github.com/alife-data-standards/alife-std-dev-python/actions/workflows/python-app.yml)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/0305e8a814e04d4395c25a70b2908651)](https://www.codacy.com/gh/alife-data-standards/alife-std-dev-python/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=alife-data-standards/alife-std-dev-python&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/alife-data-standards/alife-std-dev-python/branch/master/graph/badge.svg?token=FGMQICJ2SK)](https://codecov.io/gh/alife-data-standards/alife-std-dev-python)

This is the repository for the ALifeStdDev Python package, which contains Python
development utilities for working with [standardized](https://github.com/alife-data-standards/alife-data-standards)
ALife data.
